from datetime import datetime
from nanoid import generate # poetry add nanoid

def get_current_date() -> str:
    return datetime.utcnow().strftime("%Y%m%d")

def get_current_datetime() -> str:
    return datetime.utcnow().strftime("%Y%m%d_%H%M%S")

def get_random_file_name(file_name: str) -> str:
    rid = generate(size=10)
    return f'{get_current_datetime()}_{rid}_{file_name}'




import argparse
import sfdevtools.observability.log_helper as lh
import logging

def init_argparse() -> argparse.Namespace:
    parser = argparse.ArgumentParser(description="sfdevtools Inputs")
    # parser.add_argument("-a", "--action", required=True)
    # parser.add_argument("-l", "--lang", required=True)
    # parser.add_argument("-pn", "--projectName", default="")
    return parser.parse_args()

def main():
    logger = lh.init_logger(logger_name="sfdevtools_logger", is_json_output=False)
    args = init_argparse()
    logger.info(f"We get args: {args}")

    # Here put your logic

if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peacock.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rpeacock.proto\x12\x07peacock\">\n\x13SaveFileToColud_Msg\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66ile_content\x18\x02 \x01(\t\"\x1a\n\tNoneReply\x12\r\n\x05reply\x18\x01 \x01(\t\"\x17\n\x04Ping\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x17\n\x04Pong\x12\x0f\n\x07message\x18\x01 \x01(\t2{\n\x07Peacock\x12\x43\n\x0fSaveFileToColud\x12\x1c.peacock.SaveFileToColud_Msg\x1a\x12.peacock.NoneReply\x12+\n\x0bHealthCheck\x12\r.peacock.Ping\x1a\r.peacock.Pongb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peacock_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SAVEFILETOCOLUD_MSG._serialized_start=26
  _SAVEFILETOCOLUD_MSG._serialized_end=88
  _NONEREPLY._serialized_start=90
  _NONEREPLY._serialized_end=116
  _PING._serialized_start=118
  _PING._serialized_end=141
  _PONG._serialized_start=143
  _PONG._serialized_end=166
  _PEACOCK._serialized_start=168
  _PEACOCK._serialized_end=291
# @@protoc_insertion_point(module_scope)



import threading

class SDC(object):
    # resources shared by each and every
    # instance

    __singleton_lock = threading.Lock()
    __singleton_instance = None

    # define the classmethod
    @classmethod
    def instance(cls):

        # check for the singleton instance
        if not cls.__singleton_instance:
            with cls.__singleton_lock:
                if not cls.__singleton_instance:
                    cls.__singleton_instance = cls()

        # return the singleton instance
        return cls.__singleton_instance



import logging
import boto3 # poetry add boto3
from datetime import datetime
from nanoid import generate # poetry add nanoid
from pathlib import Path
import os
import sfdevtools.devTools.DatetimeTools as dtt

class AWSObjectStorage(object):
    def __init__(self, logger: logging.Logger):
        self.__logger = logger
        self.__s3_client = boto3.client("s3")

    def __del__(self):
        self.__s3_client.close()

    def upload_file_from_memory(self
                                , file_name: str
                                , file_content: str
                                , bucket_name: str
                                , obj_name: str) -> None:
        """! upload_file_from_memory
        @file_name file name, "test.csv"
        @file_content file content in memory
        @bucket_name s3 bucket name
        @obj_name object name on s3, example "other/cur_date/test.csv"

        @return None
        """
        temp_file_name: str = dtt.get_random_file_name(file_name=file_name)
        # temp_file_name: Path = Path.joinpath(Path(__file__).parent, temp_file_name)
        temp_file_name: Path = Path.joinpath("tmp", temp_file_name)

        with open(temp_file_name.name, "w") as FH:
            FH.write(file_content)
        self.__s3_client.upload_file(temp_file_name.name, bucket_name, obj_name)

        if os.path.exists(temp_file_name.name):
            os.remove(temp_file_name.name)

    def list_objects(self, bucket_name: str) -> None:
        """! list_objects
        @bucket_name s3 bucket name

        @return None
        """
        response = self.__s3_client.list_objects(Bucket=bucket_name)
        self.__logger.info(response["Contents"])



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sfdevtools',
 'sfdevtools.app',
 'sfdevtools.devTools',
 'sfdevtools.grpc_protos',
 'sfdevtools.observability',
 'sfdevtools.observability.logging_json',
 'sfdevtools.observability.logstash',
 'sfdevtools.storage',
 'sfdevtools.storage.objectStorage']

package_data = \
{'': ['*']}

install_requires = \
['boto3>=1.26.61,<2.0.0',
 'grpcio-tools>=1.51.1,<2.0.0',
 'grpcio>=1.51.1,<2.0.0',
 'nanoid>=2.0.0,<3.0.0',
 'pandas>=1.5.3,<2.0.0']

setup_kwargs = {
    'name': 'sfdevtools',
    'version': '1.13.0',
    'description': '',
    'long_description': '## How to publish to pypi\n```bash\n# set up pypi token\npoetry config pypi-token.pypi my-token\n\n# build the project\npoetry build\n\n# publish the project\npoetry publish\n\n# DONE\n```\n\n## Generate source code from protobuf\n```bash\n$ poetry add grpcio-tools\n$ poetry add grpcio\n$ cd sfdevtools/\n$ poetry run python -m grpc_tools.protoc -I ./grpc_protos --python_out=./grpc_protos/ --grpc_python_out=./grpc_protos/ ./grpc_protos/peacock.proto\n```\n\n## Demo example\n### Double check lock for singleton\n```python\nimport sfdevtools.observability.log_helper as lh\nimport logging\nlogger = lh.init_logger(logger_name="sfdevtools_logger", is_json_output=False)\n# create class X\nclass X(SDC):\n    pass\n\n# create class Y\nclass Y(SDC):\n    pass\n\nA1, A2 = X.instance(), X.instance()\nB1, B2 = Y.instance(), Y.instance()\n\nassert A1 is not B1\nassert A1 is A2\nassert B1 is B2\n\nlogger.info(\'A1 : {}\'.format(A1))\nlogger.info(\'A2 : {}\'.format(A2))\nlogger.info(\'B1 : {}\'.format(B1))\nlogger.info(\'B2 : {}\'.format(B2))\n```\n\n### Send log to logstash\n```python\nlogger = lh.init_logger(logger_name="connection_tester_logger"\n                        , is_json_output=False\n                        , is_print_to_console=True\n                        , is_print_to_logstash=True\n                        , logstash_host="<the host name>"\n                        , logstash_port=5960\n                        , logstash_user_tags=["Test001", "Test002"])\nlogger.info("Test Message from test")\nlogger.error("Test Message from test")\nlogger.warning("Test Message from test")\n```\n',
    'author': 'SulfredLee',
    'author_email': 'sflee1112@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
